@@ -1,5 +1,5 @@
 /*
- * $Id: buildreq.c,v 1.3 1998/05/06 21:55:10 lf Exp $
+ * $Id: buildreq.c,v 1.4 1998/12/11 11:24:28 lf Exp $
  *
  * Copyright (C) 1995,1997 Lars Fenneberg
  *
@@ -64,7 +64,6 @@ unsigned char rc_get_seqnbr(void)
 	if ((sf = fopen(seqfile, "a+")) == NULL)
 	{
 		rc_log(LOG_ERR,"rc_get_seqnbr: couldn't open sequence file %s: %s", seqfile, strerror(errno)); 
-		fclose(sf); /* just in case */
 		/* well, so guess a sequence number */
 		return rc_guess_seqnbr(); 
 	}	
@@ -99,7 +98,7 @@ unsigned char rc_get_seqnbr(void)
 	ftruncate(fileno(sf),0);
 	fprintf(sf,"%d\n", (seq_nbr+1) & UCHAR_MAX);
 	
-	fflush(sf); /* fflush because a process may read it between the flock and fclose */
+	fflush(sf); /* fflush because a process may read it between the do_unlock and fclose */
 	
 	if (do_unlock(fileno(sf)) != 0)
 		rc_log(LOG_ERR, "rc_get_seqnbr: couldn't release lock on %s: %s", seqfile, strerror(errno));
