@@ -1,7 +1,7 @@
 /*
- * $Id: config.c,v 1.11 1996/09/15 11:36:29 lf Exp $
+ * $Id: config.c,v 1.4 1998/02/10 13:29:57 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996,1997 Lars Fenneberg
  *
  * Copyright 1992 Livingston Enterprises, Inc.
  *
@@ -14,24 +14,10 @@
  *
  */
 
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
-#include <stdio.h>
-#include <ctype.h>
-#include <string.h>
-#include <sys/stat.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <netdb.h>
-#include <syslog.h>
-
-#include "config.h"
-#include "radius.h"
-#include "options.h"
-
-static OPTION *first_option;
+#include <config.h>
+#include <includes.h>
+#include <radiusclient.h>
+#include <options.h>
 
 static int test_config(char *);
 
@@ -202,9 +188,8 @@ int rc_read_config(char *filename)
 {
 	FILE *configfd;
 	char buffer[512], *p;
-	OPTION *option, *last_option;
+	OPTION *option;
 	int line, pos;
-	off_t start, end;
 
 	if ((configfd = fopen(filename,"r")) == NULL)
 	{
@@ -212,23 +197,10 @@ int rc_read_config(char *filename)
 		return (-1);
 	}
 
-	if ((option = find_option("config_file", OT_STR)) != NULL) {
-		if (set_option_str("config_file", 0, option, filename) < 0) {
-			rc_log(LOG_CRIT, "Grumpf... set_option_str(\"config,file\", ...) failed");
-			return (-1);
-		}
-		option->status = ST_CLEAN;
-	} else {
-		rc_log(LOG_CRIT, "Aiiiieeeeeee... option list is corrupt!");
-		return (-1);
-	}
-
 	line = 0;
-	last_option = NULL;
-	while (((start = ftell(configfd)) >= 0) && (fgets(buffer, sizeof(buffer), configfd) != NULL))
+	while ((fgets(buffer, sizeof(buffer), configfd) != NULL))
 	{
 		line++;
-		end = ftell(configfd)-1;
 		p = buffer;
 		
 		if ((*p == '\n') || (*p == '#') || (*p == '\0'))
@@ -254,9 +226,6 @@ int rc_read_config(char *filename)
 			return (-1);
 		}
 
-		option->start = start;
-		option->end = end;
-
 		p += pos+1;
 		while (isspace(*p)) 
 			p++;
@@ -282,15 +251,6 @@ int rc_read_config(char *filename)
 				rc_log(LOG_CRIT, "rc_read_config: impossible case branch!");
 				abort();
 		}
-		
-		option->status = ST_CLEAN;
-		
-		if (last_option != NULL)
-			last_option->next = option;
-		else
-			first_option = option;
-			
-		last_option = option;
 	}
 	fclose(configfd);
 
@@ -347,258 +307,6 @@ SERVER *rc_conf_srv(char *optname)
 	}
 }
 
-/*
- * Function: rc_conf_set
- *
- * Purpose: set a config value
- * 
- * Returns: 0 on success, -1 on failure
- */
-
-int rc_conf_set(char *filename, int line, char *optname, char *p)
-{
-	OPTION *option;
-
-	if ((option = find_option(optname, OT_ANY)) == NULL) {
-		rc_log(LOG_WARNING, "rc_conf_set: unrecognized keyword: %s", optname);
-		return (-1);
-	}
-
-	switch (option->type) {
-		case OT_STR:
-			if (set_option_str(filename, line, option, p) < 0) 
-				return (-1);
-			break;					
-		case OT_INT:
-			if (set_option_int(filename, line, option, p) < 0) 
-				return (-1);
-			break;
-		case OT_SRV:
-			if (set_option_srv(filename, line, option, p) < 0) 
-				return (-1);
-			break;
-		case OT_AUO:
-			if (set_option_auo(filename, line, option, p) < 0) 
-				return (-1);
-			break;
-		default:
-			rc_log(LOG_CRIT, "rc_conf_set: impossible case branch!");
-			abort();
-	}
-
-	option->status = ST_DIRTY;
-	
-	return 0;
-}
-
-/*
- * Function: write_option
- *
- * Purpose: writes out an option as a string
- * 
- * Returns: 0 on success, -1 on failure
- */
-
-static int write_option(FILE *fd, OPTION *option)
-{
-	SERVER *srv;
-	int i, auo;
-	
-	switch (option->type) {
-		case OT_STR:
-			fprintf(fd, "%s\t%s\n", option->name, (char *)option->val); 
-			break;					
-		case OT_INT:
-		    fprintf(fd, "%s\t%d\n", option->name, *(int *)option->val);
-			break;
-		case OT_SRV:
-			fprintf(fd, "%s\t", option->name);
-			
-			srv = (SERVER *)option->val;
-			
-			for (i = 0; i < srv->max; i++) {
-				
-				fprintf(fd,"%s:%d%s", srv->name[i], srv->port[i],
-				        (i < (srv->max - 1))?",":"");
-				
-			}
-			
-			fputs("\n", fd);
-			
-			break;
-		case OT_AUO:
-			fprintf(fd,"%s\t", option->name);
-			
-			auo = *(int *)option->val;
-			
-			if (auo & AUTH_LOCAL_FST)
-				fputs("local", fd);
-			else if (auo & AUTH_RADIUS_FST)
-				fputs("radius", fd);
-
-			if (auo & AUTH_LOCAL_SND)
-				fputs(",local", fd);
-			else if (auo & AUTH_RADIUS_SND)
-				fputs(",radius", fd);
-
-			fputs("\n", fd);
-
-			break;
-		default:
-			rc_log(LOG_CRIT, "rc_conf_set: impossible case branch!");
-			abort();
-	}
-
-	return 0;
-}
-
-/*
- * Function: write_clean_parts
- *
- * Purpose: write to clean parts of a config file out to another file
- * 
- * Returns: 0 on success, -1 on failure
- */
-
-static int write_clean_parts(FILE *src, FILE *dst, off_t start, off_t end)
-{
-	off_t written, to_read, to_write;
-	char buf[4096];
-
-	to_read = end - start + 1;
-
-	fseek(src, start, SEEK_SET);
-
-	while ((to_read > 0) &&
-			((to_write = fread(buf, 1, MIN(sizeof(buf), to_read), src)) > 0)) {
-		
-		to_read -= to_write;
-		
-		while (to_write > 0) {
-			written = fwrite(buf, 1, to_write, dst);
-					
-			if (written == 0) {
-				rc_log(LOG_ERR,"write_clean_parts: write error: %s", strerror(errno));
-				return (-1);
-			}
-									
-   			to_write -= written;
-		}
-	}
-		
-	if (to_read != 0) {
-		rc_log(LOG_ERR,"write_clean_parts: read error: %s", strerror(errno));
-		return (-1);
-	}
-	
-	return 0;
-}
-
-/*
- * Function: rc_conf_save
- *
- * Purpose: write out all changed options of a config file
- * 
- * Returns: 0 on success, -1 on failure
- */
-
-int rc_conf_save(void)
-{
-	FILE *cfd, *tmp;
-	OPTION *option;
-	char *filename, tmpname[PATH_MAX];
-	off_t start, end, size;
-	struct stat st;
-	
-	filename = rc_conf_str("config_file");
-	
-	if ((cfd = fopen(filename , "r")) == NULL) {
-		rc_log(LOG_ERR,"rc_read_config: can't open %s: %s", filename, strerror(errno));
-		return (-1);
-	}
-
-	if (stat(filename, &st) < 0) {
-		rc_log(LOG_ERR,"can't stat %s: %s", filename, strerror(errno));
-			
-		fclose(cfd);
-			
-		return (-1);
-	}
-
-	size = st.st_size;
-	
-	snprintf(tmpname, sizeof(tmpname), "%s.%d", filename, getpid());
-	if ((tmp = fopen(tmpname , "w")) == NULL) {
-		rc_log(LOG_ERR,"rc_conf_save: can't open %s: %s", tmpname, strerror(errno));
-		return (-1);
-	}
-	
-	option = first_option;
-
-	while (option) {
-
-		if (option->status == ST_CLEAN) {
-		
-			if (option == first_option)
-				start = 0;
-			else
-				start = option->start;
-
-			if (option->next == NULL)
-				end = size - 1;
-			else
-				end = option->next->start - 1;
-		
-			write_clean_parts(cfd, tmp, start, end);
-				
-		} else if (option->status == ST_DIRTY) {
-
-			if (option == first_option) {
-				start = 0;
-				end = option->start - 1;
-
-				write_clean_parts(cfd, tmp, start, end);
-			}
-			
-			write_option(tmp, option);
-
-			start = option->end + 1;
-	
-			if (option->next == NULL)
-				end = size - 1;
-			else
-				end = option->next->start - 1;
-		
-			write_clean_parts(cfd, tmp, start, end);
-		
-		} else {
-			rc_log(LOG_ERR,"rc_conf_save: impossible status: %d", option->status);
-			return (-1);
-		}
-
-		option = option->next;
-	}
-
-	fclose(tmp);
-	fclose(cfd);
-
-	if (rename(tmpname, filename) < 0)  {
-		rc_log(LOG_ERR, "can't rename %s to %s: %s", tmpname, filename, strerror(errno));
-		unlink(tmpname);
-		return (-1);
-	}
-
-	/* mark all options clean */
-	
-	option = first_option;
-	while (option) {
-		option->status = ST_CLEAN;
-		option = option->next;
-	}
-
-	return 0;
-}
-
 /*
  * Function: test_config
  *
@@ -609,8 +317,10 @@ int rc_conf_save(void)
 
 static int test_config(char *filename)
 {
+#if 0
 	struct stat st;
 	char	    *file;
+#endif
 
 	if (!(rc_conf_srv("authserver")->max))
 	{
@@ -622,9 +332,9 @@ static int test_config(char *filename)
 		rc_log(LOG_ERR,"%s: no acctserver specified", filename);
 		return (-1);
 	}
-	if (!rc_conf_str("clients"))
+	if (!rc_conf_str("servers"))
 	{
-		rc_log(LOG_ERR,"%s: no clients file specified", filename);
+		rc_log(LOG_ERR,"%s: no servers file specified", filename);
 		return (-1);
 	}                                                                         
 	if (!rc_conf_str("dictionary"))
@@ -644,6 +354,7 @@ static int test_config(char *filename)
 		return (-1);
 	}	
 
+#if 0
 	file = rc_conf_str("login_local");
 	if (stat(file, &st) == 0)
 	{
@@ -666,6 +377,7 @@ static int test_config(char *filename)
 		rc_log(LOG_ERR,"%s: file not found: %s", filename, file);
 		return (-1);
 	}
+#endif
 	
 	if (rc_conf_int("login_tries") <= 0)
 	{
@@ -739,7 +451,7 @@ static int find_match (UINT4 *ip_addr, char *hostname)
 /*
  * Function: rc_find_server
  *
- * Purpose: search a server in the clients file
+ * Purpose: search a server in the servers file
  *
  * Returns: 0 on success, -1 on failure
  *
@@ -761,9 +473,9 @@ int rc_find_server (char *server_name, UINT4 *ip_addr, char *secret)
 	if ((*ip_addr = rc_get_ipaddr (server_name)) == (UINT4) 0)
 		return (-1);
 
-	if ((clientfd = fopen (rc_conf_str("clients"), "r")) == (FILE *) NULL)
+	if ((clientfd = fopen (rc_conf_str("servers"), "r")) == (FILE *) NULL)
 	{
-		rc_log(LOG_ERR, "rc_find_server: couldn't open file: %s: %s", strerror(errno), rc_conf_str("clients"));
+		rc_log(LOG_ERR, "rc_find_server: couldn't open file: %s: %s", strerror(errno), rc_conf_str("servers"));
 		return (-1);
 	}
 	
@@ -836,7 +548,7 @@ int rc_find_server (char *server_name, UINT4 *ip_addr, char *secret)
 		memset (buffer, '\0', sizeof (buffer));
 		memset (secret, '\0', sizeof (secret));
 		rc_log(LOG_ERR, "rc_find_server: couldn't find RADIUS server %s in %s",
-			 server_name, rc_conf_str("clients"));
+			 server_name, rc_conf_str("servers"));
 		return (-1);
 	}
 	return 0;
