@@ -1,7 +1,7 @@
 /*
- * $Id: env.c,v 1.3 1996/09/15 11:36:29 lf Exp $
+ * $Id: env.c,v 1.2 1997/12/25 23:28:10 lf Exp $
  *
- * Copyright (C) 1995,1996 Lars Fenneberg
+ * Copyright (C) 1995,1996,1997 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at lf@elemental.net 
@@ -9,13 +9,9 @@
  *
  */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <syslog.h>
-
-#include "config.h"
-#include "radius.h"
+#include <config.h>
+#include <includes.h>
+#include <radiusclient.h>
 
 /*
  * Function: rc_new_env
@@ -82,7 +78,7 @@ int rc_add_env(ENV *env, char *name, char *value)
 
 	if (env->env[i])
 	{
-		if ((new_env = realloc(env->env[i], strlen(name)+strlen(value)+1)) == NULL)
+		if ((new_env = realloc(env->env[i], strlen(name)+strlen(value)+2)) == NULL)
 			return (-1);
 
 		env->env[i] = new_env;
@@ -94,7 +90,7 @@ int rc_add_env(ENV *env, char *name, char *value)
 			return (-1);
 		}
 	
-		if ((env->env[env->size] = malloc(strlen(name)+strlen(value)+1)) == NULL) {
+		if ((env->env[env->size] = malloc(strlen(name)+strlen(value)+2)) == NULL) {
 			rc_log(LOG_CRIT, "rc_add_env: out of memory");
 			return (-1);
 		}
