@@ -1,7 +1,7 @@
 /*
- * $Id: log.c,v 1.9 1996/09/15 11:36:29 lf Exp $
+ * $Id: log.c,v 1.3 1997/12/29 23:07:22 lf Exp $
  *
- * Copyright (C) 1995 Lars Fenneberg
+ * Copyright (C) 1995,1996,1997 Lars Fenneberg
  *
  * See the file COPYRIGHT for the respective terms and conditions. 
  * If the file is missing contact me at lf@elemental.net 
@@ -9,13 +9,9 @@
  *
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <syslog.h>
-
-#include "config.h"
-#include "radius.h"
+#include <config.h>
+#include <includes.h>
+#include <radiusclient.h>
 
 /*
  * Function: rc_openlog
@@ -30,7 +26,7 @@
 
 void rc_openlog(char *ident)
 {
-	openlog(ident, LOG_PID, SYSLOG_FACILITY);
+	openlog(ident, LOG_PID, RC_LOG_FACILITY);
 }
 
 /*
